@@ -32,4 +32,4 @@ if __name__ == "__main__":
 
 from .main import main
 
-sys.exit( main( argv=sys.argv[1:] ))
+sys.exit( main() )
