@@ -5,10 +5,10 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import logging
-import sys, os
+import sys
+import os
 
-sys.path.insert( 0, os.path.dirname(os.path.abspath( __file__ )))
-import tnetstrings
+from   cpppo.server import tnetstrings # reference implementation
 
 
 def test_tnetstrings():
